<?php declare(strict_types=1);

namespace App\Domains\Driver\Controller;

use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Response;
use App\Domains\Driver\Service\Controller\UpdateDevice as ControllerService;

class UpdateDevice extends ControllerAbstract
{
    /**
     * @param int $id
     *
     * @return \Illuminate\Http\Response|\Illuminate\Http\RedirectResponse
     */
    public function __invoke(int $id): Response|RedirectResponse
    {
        $this->row($id);

        if ($response = $this->actionPost('updateDevice')) {
            return $response;
        }

        $this->meta('title', __('driver-update-device.meta-title', ['title' => $this->row->name]));

        return $this->page('driver.update-device', $this->data());
    }

    /**
     * @return array
     */
    protected function data(): array
    {
        return ControllerService::new($this->request, $this->auth, $this->row)->data();
    }

    /**
     * @return \Illuminate\Http\RedirectResponse
     */
    protected function updateDevice(): RedirectResponse
    {
        $this->action()->updateDevice();

        $this->sessionMessage('success', __('driver-update-device.success'));

        return redirect()->route('driver.update.device', $this->row->id);
    }
}
